/**
 * vue-inertia-composable
 *
 * @description Inertia for Vue2 Composition API.
 * @author Logue <logue@hotmail.co.jp>
 * @copyright 2022 By Masashi Yoshikawa All rights reserved.
 * @license MIT
 * @version 0.2.1
 * @see {@link https://github.com/logue/vue-inertia-composable}
 */

var InertiaComposable = (function (exports, Vue, ziggy) {
  'use strict';

  const _interopDefaultLegacy = e => e && typeof e === 'object' && 'default' in e ? e : { default: e };

  const ziggy__default = /*#__PURE__*/_interopDefaultLegacy(ziggy);

  function useHeadManager() {
    const instance = Vue.getCurrentInstance();
    if (instance) {
      return instance.proxy.$headManager;
    } else {
      warn();
    }
    return void 0;
  }
  function usePage() {
    const instance = Vue.getCurrentInstance();
    if (instance) {
      return instance.proxy.$page;
    } else {
      warn();
    }
    return void 0;
  }
  function useInertia() {
    const instance = Vue.getCurrentInstance();
    if (instance) {
      return instance.proxy.$inertia;
    } else {
      warn();
    }
    return void 0;
  }
  function useForm(args) {
    const instance = Vue.getCurrentInstance();
    if (instance) {
      return instance.proxy.$inertia.form(args);
    } else {
      warn();
    }
    return void 0;
  }
  function route(name, params, absolute, config) {
    const instance = Vue.getCurrentInstance();
    if (instance) {
      return instance.proxy.route(name, params, absolute, config);
    }
    return ziggy__default.default(name, params, absolute, config);
  }
  const warn = () => console.warn(
    `[Inertia Composable] getCurrentInstance() returned null. Method must be called at the top of a setup() function.`
  );
  if (window.route === void 0) {
    window.route = route;
  }

  exports.route = route;
  exports.useForm = useForm;
  exports.useHeadManager = useHeadManager;
  exports.useInertia = useInertia;
  exports.usePage = usePage;

  Object.defineProperties(exports, { __esModule: { value: true }, [Symbol.toStringTag]: { value: 'Module' } });

  return exports;

})({}, Vue, ziggy);
